        function getT(rr,cc){
       if(rr==1 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==1 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 23 <br>1,3,4,5,6,7,9,10,15,17,18,22,28,30,32,36,38,39,41,42,43,46,48';}
       if(rr==1 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>11</strong> miembros: 18 <strong>control</strong><br>0,2,11,12,13,14,21,23,24,29,31,34,35,37,45,47,49,50';}
       if(rr==1 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>8</strong> miembros: 10 <br>8,16,19,20,25,26,27,33,40,44';}
       if(rr==8 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260623 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==8 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260623 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 23 <br>1,3,4,5,6,7,9,10,15,17,18,22,28,30,32,36,38,39,41,42,43,46,48';}
       if(rr==8 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260623 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>11</strong> miembros: 18 <strong>control</strong><br>0,2,11,12,13,14,21,23,24,29,31,34,35,37,45,47,49,50';}
       if(rr==8 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260623 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>8</strong> miembros: 10 <br>8,16,19,20,25,26,27,33,40,44';}
       if(rr==18 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260623 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==18 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260623 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 23 <br>1,3,4,5,6,7,9,10,15,17,18,22,28,30,32,36,38,39,41,42,43,46,48';}
       if(rr==18 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260623 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>11</strong> miembros: 18 <strong>control</strong><br>0,2,11,12,13,14,21,23,24,29,31,34,35,37,45,47,49,50';}
       if(rr==18 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260623 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>8</strong> miembros: 10 <br>8,16,19,20,25,26,27,33,40,44';}
       if(rr==24 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260623 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==24 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260623 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 23 <br>1,3,4,5,6,7,9,10,15,17,18,22,28,30,32,36,38,39,41,42,43,46,48';}
       if(rr==24 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260623 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>11</strong> miembros: 18 <strong>control</strong><br>0,2,11,12,13,14,21,23,24,29,31,34,35,37,45,47,49,50';}
       if(rr==24 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260623 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>8</strong> miembros: 10 <br>8,16,19,20,25,26,27,33,40,44';}
       if(rr==44 && cc==0){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==44 && cc==1){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 23 <br>1,3,4,5,6,7,9,10,15,17,18,22,28,30,32,36,38,39,41,42,43,46,48';}
       if(rr==44 && cc==2){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>11</strong> miembros: 18 <strong>control</strong><br>0,2,11,12,13,14,21,23,24,29,31,34,35,37,45,47,49,50';}
       if(rr==44 && cc==3){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>8</strong> miembros: 10 <br>8,16,19,20,25,26,27,33,40,44';}
       if(rr==45 && cc==0){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260623 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==45 && cc==1){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260623 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 23 <br>1,3,4,5,6,7,9,10,15,17,18,22,28,30,32,36,38,39,41,42,43,46,48';}
       if(rr==45 && cc==2){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260623 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>11</strong> miembros: 18 <strong>control</strong><br>0,2,11,12,13,14,21,23,24,29,31,34,35,37,45,47,49,50';}
       if(rr==45 && cc==3){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260623 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>8</strong> miembros: 10 <br>8,16,19,20,25,26,27,33,40,44';}
}
